AlignmentAttributeBuilder class

Builder for paragraph alignment attribute styles.

There is no need to use this class directly, consider using NotusAttribute.alignment instead.

Inheritance

Properties

center → NotusAttribute<String>
Formats a block of lines to center
no setter
end → NotusAttribute<String>
Formats a block of lines to end
no setter
hashCode → int
The hash code for this object.
no setterinherited
justify → NotusAttribute<String>
Formats a block of lines to justify
no setter
key → String
Unique key of this attribute.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotusAttributeScope
finalinherited
unset → NotusAttribute<String>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(String? value) → NotusAttribute<String>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited