fromInt method
Creates a background color attribute with specified color value.
Implementation
NotusAttribute<int> fromInt(int value) =>
NotusAttribute<int>._(key, scope, value);
Creates a background color attribute with specified color value.
NotusAttribute<int> fromInt(int value) =>
NotusAttribute<int>._(key, scope, value);