ColorAttributeBuilder class

Builder for color attribute values.

There is no need to use this class directly, consider using NotusAttribute.color instead.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Unique key of this attribute.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotusAttributeScope
finalinherited
unset → NotusAttribute<int>
no setterinherited

Methods

fromInt(int value) → NotusAttribute<int>
Creates a color attribute with specified color value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(int? value) → NotusAttribute<int>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited