EmbeddableObject class

An object which can be embedded into a Notus document.

See also:

Constructors

EmbeddableObject(String type, {required bool inline, Map<String, dynamic> data = const {}})

Properties

data → Map<String, dynamic>
The data payload of this object.
no setter
hashCode → int
The hash code for this object.
no setteroverride
inline → bool
If set to true then this object can be embedded inline with regular text, otherwise it occupies an entire line.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of this object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic> json) → EmbeddableObject

Constants

kInlineKey → const String
Key of the "inline" attribute in the data map. This key is reserved.
kTypeKey → const String
Key of the "type" attribute in the data map. This key is reserved.