insert abstract method
Insert data at specified character index with style style.
Implementation
void insert(int index, Object data, NotusStyle? style);
Insert data at specified character index with style style.
void insert(int index, Object data, NotusStyle? style);