NotusStyle class

Collection of style attributes.

Constructors

NotusStyle()

Properties

hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
Returns true if this attribute set is empty.
no setter
isInline → bool
Returns true if this style is not empty and contains only inline-scoped attributes and is not empty.
no setter
isNotEmpty → bool
Returns true if this attribute set is note empty.
no setter
keys → Iterable<String>
Returns collection of all attribute keys in this set.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → NotusAttribute
Checks that this style has only one attribute, and returns that attribute.
no setter
values → Iterable<NotusAttribute>
Returns collection of all attributes in this set.
no setter

Methods

contains(NotusAttributeKey key) → bool
Returns true if attribute with key is present in this set.
containsSame(NotusAttribute attribute) → bool
Returns true if this set contains attribute with the same value as attribute.
get<T>(NotusAttributeKey<T> key) → NotusAttribute<T>?
Returns NotusAttribute from this set by specified key.
merge(NotusAttribute attribute) → NotusStyle
Merges this attribute set with attribute and returns result as a new attribute set.
mergeAll(NotusStyle other) → NotusStyle
Merges all attributes from other into this style and returns result as a new instance of NotusStyle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(NotusAttribute attribute) → NotusStyle
Puts attribute into this attribute set and returns result as a new set.
removeAll(Iterable<NotusAttribute> attributes) → NotusStyle
Removes attributes from this style and returns new instance of NotusStyle containing result.
toJson() → Map<String, dynamic>?
Returns JSON-serializable representation of this style.
toString() → String
A string representation of this object.
override
value<T>(NotusAttributeKey<T> key) → T?
Returns value of specified attribute key in this set.

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? data) → NotusStyle