StyledNode class abstract

An interface for document nodes with style.

Implemented types

Constructors

StyledNode()

Properties

documentOffset → int
Offset in characters of this node in the document.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isFirst → bool
Returns true if this node is the first node in the parent list.
no setterinherited
isLast → bool
Returns true if this node is the last node in the parent list.
no setterinherited
length → int
Length of this node in characters.
no setterinherited
list → LinkedList<Node>?
The linked list containing this element.
no setterinherited
mounted → bool
Returns true if this node is currently mounted, e.g. parent is not null.
no setterinherited
next → Node?
The successor of this element in its linked list.
no setterinherited
offset → int
Offset in characters of this node relative to parent node.
no setterinherited
parent → ContainerNode<Node>?
Current parent of this node. May be null if this node is not mounted.
no setterinherited
previous → Node?
The predecessor of this element in its linked list.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → NotusStyle
Style of this node.
no setter

Methods

containsOffset(int offset) → bool
Returns true if this node contains character at specified offset in the document.
inherited
delete(int index, int? length) → void
Delete length characters of this node starting from index.
inherited
insert(int index, Object data, NotusStyle? style) → void
Insert data at specified character index with style style.
inherited
insertAfter(Node entry) → void
Insert an element after this element in this element's linked list.
inherited
insertBefore(Node entry) → void
Insert an element before this element in this element's linked list.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() → void
Optimize this node within parent.
inherited
retain(int index, int length, NotusStyle style) → void
Format length characters of this node starting from index with specified style style.
inherited
toDelta() → Delta
Returns Delta representation of this node.
inherited
toPlainText() → String
Returns plain-text representation of this node.
inherited
toString() → String
A string representation of this object.
inherited
Unlink the element from its linked list.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited