TextBlockTheme class

Style theme applied to a block of rich text, including single-line paragraphs.

Constructors

TextBlockTheme({required TextStyle style, required VerticalSpacing spacing, VerticalSpacing lineSpacing = const VerticalSpacing.zero(), BoxDecoration? decoration})

Properties

decoration → BoxDecoration?
Decoration of a text block.
final
hashCode → int
The hash code for this object.
no setterinherited
lineSpacing → VerticalSpacing
Vertical spacing for individual lines within a text block.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → VerticalSpacing
Vertical spacing around a text block.
final
style → TextStyle
Base text style for a text block.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited