ZefyrController class

Inheritance

Constructors

ZefyrController([NotusDocument? document])

Properties

document → NotusDocument
Document managed by this controller.
final
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
plainTextEditingValue → TextEditingValue
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection → TextSelection
Currently selected text within the document.
no setter
toggledStyles → NotusStyle
Store any styles attribute that got toggled by the tap of a button and that has not been applied yet. It gets reset after each format action within the document.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
compose(Delta change, {TextSelection? selection, ChangeSource source = ChangeSource.remote}) → void
Composes change into document managed by this controller.
dispose() → void
Discards any resources used by the object.
override
formatSelection(NotusAttribute attribute) → void
Formats current selection with attribute.
formatText(int index, int length, NotusAttribute attribute) → void
getSelectionStyle() → NotusStyle
Returns style of specified text range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replaceText(int index, int length, Object? data, {TextSelection? selection}) → void
Replaces length characters in the document starting at index with provided text.
toString() → String
A string representation of this object.
inherited
updateSelection(TextSelection value, {ChangeSource source = ChangeSource.remote}) → void
Updates selection with specified value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited