ZefyrEditor class

Widget for editing rich text documents.

Inheritance

Constructors

ZefyrEditor({Key? key, required ZefyrController controller, FocusNode? focusNode, ClipboardController? clipboardController, ScrollController? scrollController, bool scrollable = true, EdgeInsetsGeometry padding = EdgeInsets.zero, bool autofocus = false, bool showCursor = true, bool readOnly = false, bool enableInteractiveSelection = true, bool enableSuggestions = false, double? minHeight, double? maxHeight, double? scrollAreaMinHeight, bool expands = false, TextCapitalization textCapitalization = TextCapitalization.sentences, Brightness keyboardAppearance = Brightness.light, ScrollPhysics? scrollPhysics, bool? showSelectionHandles, ValueChanged<Uri>? onLaunchUrl, ZefyrEmbedBuilder embedBuilder = defaultZefyrEmbedBuilder})
const

Properties

autofocus → bool
Whether this editor should focus itself if nothing else is already focused.
final
clipboardController → ClipboardController?
The ClipboardController to use when interacting with the clipboard.
final
controller → ZefyrController
Controller object which establishes a link between a rich text document and this editor.
final
embedBuilder → ZefyrEmbedBuilder
Builder function for embeddable objects.
final
enableInteractiveSelection → bool
Whether to enable user interface affordances for changing the text selection.
final
enableSuggestions → bool
Whether to enable auto-suggestions in the system keyboard (where applicable).
final
expands → bool
Whether this editor's height will be sized to fill its parent.
final
focusNode → FocusNode?
Controls whether this editor has keyboard focus.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness
The appearance of the keyboard.
final
maxHeight → double?
The maximum height to be occupied by this editor.
final
minHeight → double?
The minimum height to be occupied by this editor.
final
onLaunchUrl → ValueChanged<Uri>?
Callback to invoke when user wants to launch a URL.
final
padding → EdgeInsetsGeometry
Additional space around the content of this editor.
final
readOnly → bool
Whether the text can be changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool
Whether this editor should create a scrollable container for its content.
final
scrollAreaMinHeight → double?
The minimum height to be available for scroll in the editor.
final
scrollController → ScrollController?
The ScrollController to use when vertically scrolling the contents.
final
scrollPhysics → ScrollPhysics?
The ScrollPhysics to use when vertically scrolling the input.
final
showCursor → bool
Whether to show cursor.
final
showSelectionHandles → bool?
Whether to show selection handles.
final
textCapitalization → TextCapitalization
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ZefyrEditorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited